@@ -7,6 +7,8 @@
 // except according to those terms.
 
 #![cfg_attr(all(not(doctest), doc), feature(doc_cfg))]
+#![allow(clippy::missing_safety_doc)]
+#![allow(clippy::non_send_fields_in_send_ty)]
 
 pub use ffi;
 pub use gst_gl;
